@@ -1,8 +1,10 @@
 use std::{
     ffi::CString,
     fmt,
-    os::unix::io::{BorrowedFd, OwnedFd},
-    os::unix::{io::RawFd, net::UnixStream},
+    os::unix::{
+        io::{BorrowedFd, OwnedFd, RawFd},
+        net::UnixStream,
+    },
     sync::Arc,
 };
 
@@ -230,7 +232,7 @@ impl fmt::Debug for GlobalId {
 ///
 /// This type hosts most of the protocol-related functionality of the backend, and is the
 /// main entry point for manipulating Wayland objects. It can be retrieved from the backend via
-/// [`Backend::handle()`](Backend::handle) and cloned, and is given to you as argument in many callbacks.
+/// [`Backend::handle()`] and cloned, and is given to you as argument in many callbacks.
 #[derive(Clone, Debug)]
 pub struct Handle {
     pub(crate) handle: server_impl::InnerHandle,
@@ -238,7 +240,7 @@ pub struct Handle {
 
 /// A weak reference to a [`Handle`]
 ///
-/// This handle behaves similarly to [`Weak`](std::sync::Weak), and can be used to keep access to
+/// This handle behaves similarly to [`Weak`][std::sync::Weak], and can be used to keep access to
 /// the handle without actually preventing it from being dropped.
 #[derive(Clone, Debug)]
 pub struct WeakHandle {
@@ -248,7 +250,8 @@ pub struct WeakHandle {
 impl WeakHandle {
     /// Try to upgrade this weak handle to a [`Handle`]
     ///
-    /// Returns `None` if the associated backend was already dropped.
+    /// Returns [`None`] if the associated backend was already dropped.
+    #[inline]
     pub fn upgrade(&self) -> Option<Handle> {
         self.handle.upgrade().map(|handle| Handle { handle })
     }
@@ -256,6 +259,7 @@ impl WeakHandle {
 
 impl Handle {
     /// Get a [`WeakHandle`] from this handle
+    #[inline]
     pub fn downgrade(&self) -> WeakHandle {
         WeakHandle { handle: self.handle.downgrade() }
     }
@@ -551,7 +555,7 @@ impl<D> Backend<D> {
     ///
     /// **Note:** This functionality is currently only available on the rust backend, invoking this method on
     /// the system backend will do the same as invoking
-    /// [`Backend::dispatch_all_clients()`](Backend::dispatch_all_clients).
+    /// [`Backend::dispatch_all_clients()`].
     #[inline]
     pub fn dispatch_single_client(
         &mut self,
@@ -576,8 +580,12 @@ impl<D> Backend<D> {
     }
 }
 
+// Workaround: Some versions of rustc throw a `struct is never constructed`-warning here,
+// if the `server_system`-feature is enabled, even though the `rs`-module makes use if it.
+#[allow(dead_code)]
 pub(crate) struct DumbObjectData;
 
+#[allow(dead_code)]
 impl<D> ObjectData<D> for DumbObjectData {
     #[cfg_attr(coverage, coverage(off))]
     fn request(
